@@ -104,20 +104,23 @@ import click
     '--verbose/--no-verbose',
     default=False,
     help='Toggle verbose logging, defaults to False.')
-@click.option(
-    '--verbose/--no-verbose',
-    default=False,
-    help='Toggle verbose logging, defaults to False.')
 @click.option(
     'log_dir', '--log-dir',
     help='The directory for the pact.log file.')
 @click.option(
     'log_level', '--log-level',
     help='The logging level.')
+@click.option(
+    'enable_pending', '--enable-pending',
+    default=False,
+    help='Allow pacts which are in pending state to be verified without causing the '
+         'overall task to fail. For more information, see https://pact.io/pending',
+    is_flag=True)
 def main(pacts, base_url, pact_url, pact_urls, states_url, states_setup_url,
          username, broker_base_url, consumer_version_tag, consumer_version_selector,
          provider_version_tag, password, token, provider, headers, timeout,
-         provider_app_version, publish_verification_results, verbose, log_dir, log_level):
+         provider_app_version, publish_verification_results, verbose, log_dir,
+         log_level, enable_pending):
     """
     Verify one or more contracts against a provider service.
 
@@ -172,7 +175,7 @@ def main(pacts, base_url, pact_url, pact_urls, states_url, states_setup_url,
         'consumer_tags': list(consumer_version_tag),
         'consumer_selectors': list(consumer_version_selector),
         'provider_tags': list(provider_version_tag),
-        'provider_states_setup_url': states_setup_url
+        'provider_states_setup_url': states_setup_url,
     }
 
     options = dict(filter(lambda item: item[1] is not None, options.items()))
@@ -182,6 +185,7 @@ def main(pacts, base_url, pact_url, pact_urls, states_url, states_setup_url,
     success, logs = VerifyWrapper().call_verify(*all_pact_urls,
                                                 provider=provider,
                                                 provider_base_url=base_url,
+                                                enable_pending=enable_pending,
                                                 **options)
     sys.exit(success)
 
